@@ -2,9 +2,11 @@
 from .searchmanga import SearchManga
 from .mangainfo import MangaInfo
 from .downloadchapter import DownloadChapter
+from .chapterinfo import ChapterInfo
 
 __ALL__ = (
     "SearchManga",
     "MangaInfo",
-    "DownloadChapter"
+    "DownloadChapter",
+    "ChapterInfo"
 )
